package betterquesting.api2.client.gui.resources.textures;

import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.resources.colors.GuiColorStatic;
import betterquesting.api2.client.gui.resources.colors.IGuiColor;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import net.minecraft.client.Minecraft;
import net.minecraft.client.renderer.Tessellator;
import net.minecraft.client.renderer.texture.TextureMap;
import net.minecraft.util.IIcon;
import net.minecraft.util.ResourceLocation;
import net.minecraftforge.fluids.FluidStack;
import org.lwjgl.opengl.GL11;

/* loaded from: betterquesting_api2_client_gui_resources_textures.jar:betterquesting/api2/client/gui/resources/textures/FluidTexture.class */
public class FluidTexture implements IGuiTexture {
    private static final IGuiColor defColor = new GuiColorStatic(255, 255, 255, 255);
    private final FluidStack fluid;
    private final boolean showCount;
    private final boolean keepAspect;
    private final IGuiRect bounds;

    public FluidTexture(FluidStack fluid) {
        this(fluid, false, true);
    }

    public FluidTexture(FluidStack fluid, boolean showCount, boolean keepAspect) {
        this.bounds = new GuiRectangle(0, 0, 16, 16);
        this.fluid = fluid;
        this.showCount = showCount;
        this.keepAspect = keepAspect;
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public void drawTexture(int x, int y, int width, int height, float zDepth, float partialTick) {
        drawTexture(x, y, width, height, zDepth, partialTick, defColor);
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public void drawTexture(int x, int y, int width, int height, float zDepth, float partialTick, IGuiColor color) {
        if (width <= 0 || height <= 0) {
            return;
        }
        float sx = width / 16.0f;
        float sy = height / 16.0f;
        double dx = 0.0d;
        double dy = 0.0d;
        if (this.keepAspect) {
            float sa = Math.min(sx, sy);
            dx = Math.floor((sx - sa) * 8.0f);
            dy = Math.floor((sy - sa) * 8.0f);
            sx = sa;
            sy = sa;
        }
        GL11.glPushMatrix();
        GL11.glTranslated(x + dx, y + dy, 0.0d);
        GL11.glScalef(sx, sy, 1.0f);
        int fCol = this.fluid.getFluid().getColor(this.fluid);
        float a = ((fCol >> 24) & 255) / 255.0f;
        float r = ((fCol >> 16) & 255) / 255.0f;
        float g = ((fCol >> 8) & 255) / 255.0f;
        float b = (fCol & 255) / 255.0f;
        GL11.glColor4f(r + (color.getRed() / 2.0f), g + (color.getGreen() / 2.0f), b + (color.getBlue() / 2.0f), a + (color.getAlpha() / 2.0f));
        Minecraft mc = Minecraft.func_71410_x();
        mc.field_71446_o.func_110577_a(TextureMap.field_110575_b);
        IIcon icon = this.fluid.getFluid().getIcon() != null ? this.fluid.getFluid().getIcon() : mc.field_71446_o.func_110581_b(TextureMap.field_110575_b).func_110572_b("missigno");
        drawTexturedModalRect(0.0d, 0.0d, 0.0d, icon, 16.0d, 16.0d);
        GL11.glPopMatrix();
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public ResourceLocation getTexture() {
        return PresetTexture.TX_NULL;
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public IGuiRect getBounds() {
        return this.bounds;
    }

    private void drawTexturedModalRect(double xCoord, double yCoord, double zDepth, IIcon textureSprite, double widthIn, double heightIn) {
        Tessellator tessellator = Tessellator.field_78398_a;
        tessellator.func_78382_b();
        tessellator.func_78374_a(xCoord, yCoord + heightIn, zDepth, textureSprite.func_94209_e(), textureSprite.func_94210_h());
        tessellator.func_78374_a(xCoord + widthIn, yCoord + heightIn, zDepth, textureSprite.func_94212_f(), textureSprite.func_94210_h());
        tessellator.func_78374_a(xCoord + widthIn, yCoord, zDepth, textureSprite.func_94212_f(), textureSprite.func_94206_g());
        tessellator.func_78374_a(xCoord, yCoord, zDepth, textureSprite.func_94209_e(), textureSprite.func_94206_g());
        tessellator.func_78381_a();
    }
}
